using System.Windows;
using System.Windows.Controls.Primitives;
using System.Windows.Input;

namespace SLAttachedBehavior
{
    public static class MouseMove
    {
        private static readonly DependencyProperty MouseMoveCommandBehaviorProperty = DependencyProperty.RegisterAttached(
            "MouseMoveCommandBehavior",
            typeof(UIElementMouseMoveCommandBehavior),
            typeof(MouseMove),
            null);

        public static readonly DependencyProperty CommandProperty = DependencyProperty.RegisterAttached(
            "Command",
            typeof(ICommand),
            typeof(MouseMove),
            new PropertyMetadata(OnSetCommandCallback));

        public static void SetCommand(UIElement element, ICommand command)
        {
            element.SetValue(CommandProperty, command);
        }

        public static ICommand GetCommand(UIElement element)
        {
            return element.GetValue(CommandProperty) as ICommand;
        }

        private static void OnSetCommandCallback(DependencyObject dependencyObject, DependencyPropertyChangedEventArgs e)
        {
            UIElement element = dependencyObject as UIElement;
            if (element != null)
            {
                UIElementMouseMoveCommandBehavior behavior = GetOrCreateBehavior(element);
                behavior.Command = e.NewValue as ICommand;
            }
        }

        private static UIElementMouseMoveCommandBehavior GetOrCreateBehavior(UIElement element)
        {
            UIElementMouseMoveCommandBehavior behavior = element.GetValue(MouseMoveCommandBehaviorProperty) as UIElementMouseMoveCommandBehavior;
            if (behavior == null)
            {
                behavior = new UIElementMouseMoveCommandBehavior(element);
                element.SetValue(MouseMoveCommandBehaviorProperty, behavior);
            }

            return behavior;
        }
    }
}